@@ -41,7 +41,8 @@ class JobClient(object):
         )
 
     def __del__(self):
-        self.channel.close()
+        if hasattr(self, 'channel'):
+            self.channel.close()
 
 
 class JobServer(object):
@@ -66,7 +67,8 @@ class JobServer(object):
 
     def job_register(self):
         for key in self.job_methods.keys():
-            result = self.channel.queue_declare(queue=key)
+            result = self.channel.queue_declare(queue='', exclusive=True)
+            queue_name = result.method.queue
 
             queue_task = self.job_methods[key]
 
@@ -74,7 +76,6 @@ class JobServer(object):
                 exchange=queue_task['exchange'],
                 exchange_type=queue_task['exchange_type']
             )
-            queue_name = result.method.queue
 
             self.channel.queue_bind(
                 exchange=queue_task['exchange'],
