@@ -1,5 +1,6 @@
 # Django
-from django.db.models.signals import post_save
+from django.db.models.signals import post_save, post_delete
+from django.db.models import Manager
 from django.conf import settings
 
 # Project
@@ -10,6 +11,11 @@ def signal_post_save(sender, instance, created, **kwargs):
     instance.send([instance])
 
 
+def signal_delete_save(sender, instance, using, **kwargs):
+    data = [{'id': instance.id, 'is_deleted': True}]
+    JobClient().call(instance.routing_key, data)
+
+
 def send(routing_key):
     @staticmethod
     def wrapper(instances):
@@ -22,7 +28,10 @@ def send(routing_key):
 
 
 def sync_model(_, model):
-    model.send(model.objects.all())
+    if hasattr(model, 'raw_objects'):
+        model.send(model.raw_objects.all())
+    else:
+        model.send(model.objects.all())
 
 
 def producer(model):
@@ -34,6 +43,9 @@ def producer(model):
 
     job_tasks(app_name, model=model)(sync_model)
 
+    model.signal_delete_save = signal_delete_save
+    post_delete.connect(model.signal_delete_save, sender=model)
+
     if hasattr(model, 'post_save_trigger'):
         return model
 
